This function essentially applies estimate_1_LBI() to each subject's
data, estimating subject-specific optimal parameters based on maximum
likelihood. Because the fitting process for each subject is independent,
the procedure can be accelerated using parallel computation.
Usage
estimate_1_MLE(
data,
colnames,
behrule,
ids = NULL,
models,
funcs = NULL,
priors,
settings = NULL,
lowers,
uppers,
control,
...
)Arguments
- data
A data frame in which each row represents a single trial, see data
- colnames
Column names in the data frame, see colnames
- behrule
The agent's implicitly formed internal rule, see behrule
- ids
The Subject ID of the participant whose data needs to be fitted.
- models
Reinforcement Learning Models
- funcs
The functions forming the reinforcement learning model, see funcs
- priors
Prior probability density function of the free parameters, see priors
- settings
Other model settings, see settings
- lowers
Lower bound of free parameters in each model.
- uppers
Upper bound of free parameters in each model.
- control
Settings manage various aspects of the iterative process, see control
- ...
Additional arguments passed to internal functions.