View source: R/estimate_2_ABC.R
| estimate_2_ABC | R Documentation |
This function takes a large set of simulated data to train an Approximate Bayesian Computation (ABC) model and then uses the trained model to estimate optimal parameters for the target data.
estimate_2_ABC(
data,
colnames,
behrule,
ids = NULL,
models,
funcs = NULL,
priors,
settings = NULL,
lowers,
uppers,
control,
...
)
data |
A data frame in which each row represents a single trial, see data |
colnames |
Column names in the data frame, see colnames |
behrule |
The agent's implicitly formed internal rule, see behrule |
ids |
The Subject ID of the participant whose data needs to be fitted. |
models |
Reinforcement Learning Models |
funcs |
The functions forming the reinforcement learning model, see funcs |
priors |
Prior probability density function of the free parameters, see priors |
settings |
Other model settings, see settings |
lowers |
Lower bound of free parameters in each model. |
uppers |
Upper bound of free parameters in each model. |
control |
Settings manage various aspects of the iterative process, see control |
... |
Additional arguments passed to internal functions. |
An S3 object of class DataFrame containing, for each model,
the estimated optimal parameters and associated model fit metrics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.