| TAB | R Documentation |
This dataset originates from Experiment 2 of Mason et al. (2024), titled "Rare and extreme outcomes in risky choice" (\Sexpr[results=rd]{tools:::Rd_expr_doi("10.3758/s13423-023-02415-x")}). The raw data is publicly available on the Open Science Framework (OSF) at https://osf.io/hy3q4/. For the purposes of this package, we've performed basic cleaning and preprocessing of the original dataset.
A data frame with 45000 rows and 11 columns:
Subject ID, an integer (total of 143).
Block number, an integer (1 to 6).
Trial number, an integer (1 to 60).
Left choice, a character indicating the option presented. The possible options are:
A: 100% gain 36.
B: 90% gain 40 and 10% gain 0.
C: 100% lose 36.
D: 90% lose 40 and 10% lose 0.
Right choice, a character indicating the option presented. The possible options are:
A: 100% gain 36.
B: 90% gain 40 and 10% gain 0.
C: 100% lose 36.
D: 90% lose 40 and 10% lose 0.
Reward associated with the left choice.
Reward associated with the right choice.
The chosen option, either L_choice or R_choice.
Type of frame, a character string (e.g., "Gain", "Loss", "Catch").
The participant's net worth at the end of each trial.
The participant's reaction time (in milliseconds) for each trial.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.