| engine_ABC | R Documentation |
Because abc::abc() requires summary statistics together with the
corresponding input parameters, this function converts the generated
simulated data into a standardized collection of summary statistics and
input parameters, facilitating subsequent execution of abc::abc().
engine_ABC(
data,
colnames,
behrule,
model,
funcs = NULL,
priors,
settings = NULL,
control = control,
...
)
data |
A data frame in which each row represents a single trial, see data |
colnames |
Column names in the data frame, see colnames |
behrule |
The agent's implicitly formed internal rule, see behrule |
model |
Reinforcement Learning Model |
funcs |
The functions forming the reinforcement learning model, see funcs |
priors |
Prior probability density function of the free parameters, see priors |
settings |
Other model settings, see settings |
control |
Settings manage various aspects of the iterative process, see control |
... |
Additional arguments passed to internal functions. |
A List containing a DataFrame of the parameters used to
generate the simulated data and the summary statistics for Approximate
Bayesian Computation (ABC).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.