| engine_RNN | R Documentation |
Because TensorFlow requires numeric arrays and input parameters to learn the mapping between them when building a Recurrent Neural Network (RNN) model, this function transforms simulated data into a standardized dataset and invokes TensorFlow to train the model.
Because TensorFlow requires numeric arrays and input parameters to learn the mapping between them when building a Recurrent Neural Network (RNN) model, this function transforms simulated data into a standardized dataset and invokes TensorFlow to train the model.
engine_RNN(
data,
colnames,
behrule,
model,
funcs = NULL,
priors,
settings = NULL,
control = control,
...
)
engine_RNN3(
data,
colnames,
behrule,
model,
funcs = NULL,
priors,
settings = NULL,
control = control,
...
)
data |
A data frame in which each row represents a single trial, see data |
colnames |
Column names in the data frame, see colnames |
behrule |
The agent's implicitly formed internal rule, see behrule |
model |
Reinforcement Learning Model |
funcs |
The functions forming the reinforcement learning model, see funcs |
priors |
Prior probability density function of the free parameters, see priors |
settings |
Other model settings, see settings |
control |
Settings manage various aspects of the iterative process, see control |
... |
Additional arguments passed to internal functions. |
A specialized Recurrent Neural Network (RNN) object.
The model can be used with the predict() function to make predictions
on a new data frame, estimating the input parameters that are most likely
to have generated the given dataset.
A specialized Recurrent Neural Network (RNN) object.
The model can be used with the predict() function to make predictions
on a new data frame, estimating the input parameters that are most likely
to have generated the given dataset.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.