estimate_2_SBI: Simulated-Based Inference (SBI)

View source: R/estimate_2_SBI.R

estimate_2_SBIR Documentation

Simulated-Based Inference (SBI)

Description

Since both Approximate Bayesian Computation (ABC) and Recurrent Neural Network (RNN) are simulation-based inference methods, they require a model built from a large amount of simulated data before running. This model is then used to predict the most likely input parameters corresponding to the real data. Therefore, this function generates random input parameters using user-specified distributions and produces simulated data based on these parameters.

Usage

estimate_2_SBI(env, model, priors, control = list(), ...)

Arguments

env

multiRL.env

model

Reinforcement Learning Model

priors

Prior probability density function of the free parameters, see priors

control

Settings manage various aspects of the iterative process, see control

...

Additional arguments passed to internal functions.

Value

A List containing, for each model, simulated data generated using randomly sampled parameters.


multiRL documentation built on March 31, 2026, 5:06 p.m.