| func_gamma | R Documentation |
U(R) = {R}^{\gamma}
func_gamma(shown, reward, params, ...)
shown |
Which options shown in this trial. |
reward |
The feedback received by the agent from the environment at trial(t) following the execution of action(a) |
params |
Parameters used by the model's internal functions, see params |
... |
It currently contains the following information; additional information may be added in future package versions.
|
A NumericVector of length one representing the subjective
value transformed from the objective reward via the utility function.
func_gamma <- function(
shown,
reward,
params,
...
){
list2env(list(...), envir = environment())
# If you need extra information(...)
# Column names may be lost(C++), indexes are recommended
# e.g.
# Trial <- idinfo[3]
# Frame <- exinfo[1]
# Action <- behave[1]
gamma <- params[["gamma"]]
# Stevens' Power Law
utility <- ((reward >= 0) * 2 - 1) * (abs(reward) ^ gamma)
return(utility)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.