plot.multiRL.replay: plot.multiRL.replay

View source: R/base_plot.R

plot.multiRL.replayR Documentation

plot.multiRL.replay

Description

plot.multiRL.replay

Usage

## S3 method for class 'multiRL.replay'
plot(x, y = NULL, model = NULL, param = NULL, metric = "BIC", ...)

Arguments

x

multiRL.replay

y

NULL

model

The name of model that you want to plot

param

The name of parameter that you want to plot

metric

The metric for identifying the optimal model defaults to BIC; if the LogL cannot be calculated, ACC is used instead.

...

extra

Value

An S3 object of class ggplot2


multiRL documentation built on March 31, 2026, 5:06 p.m.