| plot.multiRL.replay | R Documentation |
plot.multiRL.replay
## S3 method for class 'multiRL.replay'
plot(x, y = NULL, model = NULL, param = NULL, metric = "BIC", ...)
x |
multiRL.replay |
y |
NULL |
model |
The name of model that you want to plot |
param |
The name of parameter that you want to plot |
metric |
The metric for identifying the optimal model defaults to BIC; if the LogL cannot be calculated, ACC is used instead. |
... |
extra |
An S3 object of class ggplot2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.