Learn R Programming

multiRL (version 0.3.7)

plot.multiRL.replay: plot.multiRL.replay

Description

plot.multiRL.replay

Usage

# S3 method for multiRL.replay
plot(x, y = NULL, model = NULL, param = NULL, metric = "BIC", ...)

Value

An S3 object of class ggplot2

Arguments

x

multiRL.replay

y

NULL

model

The name of model that you want to plot

param

The name of parameter that you want to plot

metric

The metric for identifying the optimal model defaults to BIC; if the LogL cannot be calculated, ACC is used instead.

...

extra