plot.multiRL.replay
# S3 method for multiRL.replay
plot(x, y = NULL, model = NULL, param = NULL, metric = "BIC", ...)An S3 object of class ggplot2
multiRL.replay
NULL
The name of model that you want to plot
The name of parameter that you want to plot
The metric for identifying the optimal model defaults to BIC; if the LogL cannot be calculated, ACC is used instead.
extra