View source: R/process_1_input.R
| process_1_input | R Documentation |
multiRL.input
process_1_input(
data,
colnames = list(),
funcs = list(),
params = list(),
priors,
settings = list(),
...
)
data |
A data frame in which each row represents a single trial, see data |
colnames |
Column names in the data frame, see colnames |
funcs |
The functions forming the reinforcement learning model, see funcs |
params |
Parameters used by the model’s internal functions, see params |
priors |
Prior probability density function of the free parameters, see priors |
settings |
Other model settings, see settings |
... |
Additional arguments passed to internal functions. |
An S4 object of class multiRL.input.
dataA DataFrame containing the trial-level raw data.
colnamesAn S4 object of class multiRL.colnames,
specifying the column names used in the input data.
featuresAn S4 object of class multiRL.features,
containing standardized representations of states and actions
transformed from the raw data.
paramsAn S4 object of class multiRL.params,
containing model parameters.
priorsA List specifying prior distributions for free parameters.
funcsAn S4 object of class multiRL.funcs,
containing functions used in model.
settingsAn S4 object of class multiRL.settings,
storing global settings for model estimation.
elementsA int indicating the number of elements within states.
subidA Character string identifying the subject.
n_blockA int value indicating the number of blocks.
n_trialA int value indicating the number of trials.
n_rowsA int value indicating the number of rows in the data.
extraA List containing additional user-defined information.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.